searchData={"items":[{"type":"module","title":"SFDCQuery","doc":"The SFDC Query library","ref":"SFDCQuery.html"},{"type":"function","title":"SFDCQuery.query/2","doc":"Queries SFDC having a SFDCQuery.Config and a SOQL query returning the records","ref":"SFDCQuery.html#query/2"},{"type":"behaviour","title":"SFDCQuery.Client.Behaviour","doc":"","ref":"SFDCQuery.Client.Behaviour.html"},{"type":"callback","title":"SFDCQuery.Client.Behaviour.create/1","doc":"","ref":"SFDCQuery.Client.Behaviour.html#c:create/1"},{"type":"module","title":"SFDCQuery.Client.Default","doc":"","ref":"SFDCQuery.Client.Default.html"},{"type":"function","title":"SFDCQuery.Client.Default.create/1","doc":"Builds a new client configuration with the given arguments.\nIt fetches the values from the environment variables if they are not provided.\n  SFDC_QUERY_INSTANCE_URL\n  SFDC_QUERY_ACCESS_TOKEN\n  SFDC_QUERY_REFRESH_TOKEN\n  SFDC_QUERY_VERSION\n  SFDC_QUERY_LOGS_ENABLE","ref":"SFDCQuery.Client.Default.html#create/1"},{"type":"module","title":"SFDCQuery.Config","doc":"The configuration of the SFDCQuery library.","ref":"SFDCQuery.Config.html"},{"type":"function","title":"SFDCQuery.Config.new/1","doc":"","ref":"SFDCQuery.Config.html#new/1"},{"type":"type","title":"SFDCQuery.Config.t/0","doc":"","ref":"SFDCQuery.Config.html#t:t/0"},{"type":"behaviour","title":"SFDCQuery.Parser.Behaviour","doc":"","ref":"SFDCQuery.Parser.Behaviour.html"},{"type":"callback","title":"SFDCQuery.Parser.Behaviour.parse/1","doc":"","ref":"SFDCQuery.Parser.Behaviour.html#c:parse/1"},{"type":"module","title":"SFDCQuery.Parser.CSV","doc":"","ref":"SFDCQuery.Parser.CSV.html"},{"type":"module","title":"SFDCQuery.Parser.JSON","doc":"","ref":"SFDCQuery.Parser.JSON.html"},{"type":"module","title":"SFDCQuery.Parser.Map","doc":"","ref":"SFDCQuery.Parser.Map.html"},{"type":"module","title":"SFDCQuery.Query","doc":"","ref":"SFDCQuery.Query.html"},{"type":"function","title":"SFDCQuery.Query.new/2","doc":"","ref":"SFDCQuery.Query.html#new/2"},{"type":"type","title":"SFDCQuery.Query.t/0","doc":"","ref":"SFDCQuery.Query.html#t:t/0"},{"type":"module","title":"SFDCQuery.RestAPI","doc":"The SFDC REST API implementation","ref":"SFDCQuery.RestAPI.html"},{"type":"function","title":"SFDCQuery.RestAPI.query/2","doc":"Queries SFDC having a SFDCQuery.Config and a SOQL query returning the records","ref":"SFDCQuery.RestAPI.html#query/2"},{"type":"behaviour","title":"SFDCQuery.View.Behaviour","doc":"","ref":"SFDCQuery.View.Behaviour.html"},{"type":"callback","title":"SFDCQuery.View.Behaviour.show/1","doc":"","ref":"SFDCQuery.View.Behaviour.html#c:show/1"},{"type":"module","title":"SFDCQuery.View.CSV","doc":"","ref":"SFDCQuery.View.CSV.html"},{"type":"module","title":"SFDCQuery.View.JSON","doc":"","ref":"SFDCQuery.View.JSON.html"},{"type":"module","title":"SFDCQuery.View.Printer","doc":"","ref":"SFDCQuery.View.Printer.html"},{"type":"function","title":"SFDCQuery.View.Printer.break/0","doc":"","ref":"SFDCQuery.View.Printer.html#break/0"},{"type":"function","title":"SFDCQuery.View.Printer.line/1","doc":"","ref":"SFDCQuery.View.Printer.html#line/1"},{"type":"function","title":"SFDCQuery.View.Printer.print/2","doc":"","ref":"SFDCQuery.View.Printer.html#print/2"},{"type":"function","title":"SFDCQuery.View.Printer.print/3","doc":"","ref":"SFDCQuery.View.Printer.html#print/3"},{"type":"function","title":"SFDCQuery.View.Printer.separator/1","doc":"","ref":"SFDCQuery.View.Printer.html#separator/1"},{"type":"module","title":"SFDCQuery.View.Table","doc":"","ref":"SFDCQuery.View.Table.html"},{"type":"extras","title":"SFDCQuery","doc":"# SFDCQuery\n\nQuery Salesforce data easily formatting and viewing the data as you want!","ref":"readme.html"},{"type":"extras","title":"Installation - SFDCQuery","doc":"```elixir\ndef deps do\n  [\n    {:sdfc_query, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Using - SFDCQuery","doc":"For querying Salesforce using SFDCQuery library, you will need to define a Client and if you want, you can parse or print the query response","ref":"readme.html#using"},{"type":"extras","title":"Default Client - SFDCQuery","doc":"SFDCQuery implements SFDCQuery.Client.Default which allow to your application pass the follow args:\n\n- `instance_url` \n- `access_token`\n- `version`\n- `logs`\n\nIn case of any of those args are not passed to the function `create/1`, it'll get the values from the environment variables:\n\n- SFDC_QUERY_INSTANCE_URL\n- SFDC_QUERY_ACCESS_TOKEN\n- SFDC_QUERY_VERSION\n- SFDC_QUERY_LOGS_ENABLED\n\n \n\n```elixir \nSFDCQuery.Client.Default.create(%{\n  instance_url: \"https://sfdc_query.my.salesforce.com\",\n  access_token: \"MY ACCESS TOKEN\",\n  version: \"60.0\",\n  logs: true\n})\n\n%SFDCQuery.Config{\n  instance_url: \"https://sfdc_query.my.salesforce.com\",\n  access_token: \"MY ACCESS TOKEN\",\n  version: \"60.0\",\n  logs: true\n}\n```","ref":"readme.html#default-client"},{"type":"extras","title":"Building your own Client - SFDCQuery","doc":"SFDCQuery defines the behaviour `SFDCQuery.Client.Behaviour` allowing you to implement your own Client. It allow you to perfom your system's business rules for fetching the credentials of the Salesforce Org\n\n```elixir\ndefmodule MyApp.CustomerSFDCClient do\n  @behaviour SFDCQuery.Client.Behaviour\n\n  alias SFDCQuery.Config\n\n  alias MyApp.Ecto\n\n  import Ecto.Query\n\n  @impl true\n  def create(customer_id) do\n    credentials = from(c in Credentials, where: c.customer_id == ^customer_id) |> Repo.one()\n\n    Config.new(%{\n      instance_url: credentials.salesforce_instance_url,\n      access_token: credentials.salesforce_access_token,\n      version: credentials.salesforce_version,\n      logs: false\n    })\n  end\nend\n```","ref":"readme.html#building-your-own-client"},{"type":"extras","title":"Querying Salesforce - SFDCQuery","doc":"Having a Client, now you need to write the [SOQL](https://developer.salesforce.com/docs/atlas.en-us.soql_sosl.meta/soql_sosl/sforce_api_calls_soql.htm) to query the Salesforce\n\n\n```elixir\nSFDCQuery.Client.Default.create(args)\n|> SFDCQuery.query(\"SELECT Id, Name, Website From Account LIMIT 3\")\n\n{:ok,\n %SFDCQuery.Query{\n   soql: \"SELECT Id, Name, Website From Account LIMIT 3\",\n   fields: [\"Id\", \"Name\", \"Website\"],\n   records: [\n     %{\n       attributes: %{\n         \"type\" => \"Account\",\n         \"url\" => \"/services/data/v60.0/sobjects/Account/001U8000005CeutIAC\"\n       },\n       Name: \"Page\",\n       Id: \"001U8000005CeutIAC\",\n       Website: nil\n     },\n     %{\n       attributes: %{\n         \"type\" => \"Account\",\n         \"url\" => \"/services/data/v60.0/sobjects/Account/001U8000005cJN0IAM\"\n       },\n       Name: \"Nike\",\n       Id: \"001U8000005cJN0IAM\",\n       Website: \"https://www.nike.com/\"\n     },\n     %{\n       attributes: %{\n         \"type\" => \"Account\",\n         \"url\" => \"/services/data/v60.0/sobjects/Account/001U8000005cRAnIAM\"\n       },\n       Name: \"Google\",\n       Id: \"001U8000005cRAnIAM\",\n       Website: \"google.com\"\n     }\n   ]\n }}\n ```","ref":"readme.html#querying-salesforce"},{"type":"extras","title":"Parsing the response - SFDCQuery","doc":"#### Map\n\n```elixir\nSFDCQuery.Client.Default.create(args)\n|> SFDCQuery.query(\"SELECT Id, Name, Website From Account LIMIT 3\")\n|> SFDCQuery.Parser.Map.parse()\n\n{:ok,\n [\n    %{\n      attributes: %{\n        \"type\" => \"Account\",\n        \"url\" => \"/services/data/v60.0/sobjects/Account/001U8000005CeutIAC\"\n      },\n      Name: \"Page\",\n      Id: \"001U8000005CeutIAC\",\n      Website: nil\n    },\n    %{\n      attributes: %{\n        \"type\" => \"Account\",\n        \"url\" => \"/services/data/v60.0/sobjects/Account/001U8000005cJN0IAM\"\n      },\n      Name: \"Nike\",\n      Id: \"001U8000005cJN0IAM\",\n      Website: \"https://www.nike.com/\"\n    },\n    %{\n      attributes: %{\n        \"type\" => \"Account\",\n        \"url\" => \"/services/data/v60.0/sobjects/Account/001U8000005cRAnIAM\"\n      },\n      Name: \"Google\",\n      Id: \"001U8000005cRAnIAM\",\n      Website: \"google.com\"\n    }\n  ]\n}\n```\n\n#### JSON\n\n```elixir\nSFDCQuery.Client.Default.create(args)\n|> SFDCQuery.query(\"SELECT Id, Name, Website From Account LIMIT 3\")\n|> SFDCQuery.Parser.JSON.parse()\n\n{:ok, \"[{\\\"attributes\\\":{\\\"type\\\":\\\"Account\\\",\\\"url\\\":\\\"/services/data/v60.0/sobjects/Account/001U8000005CeutIAC\\\"},\\\"Name\\\":\\\"Page\\\",\\\"Id\\\":\\\"001U8000005CeutIAC\\\",\\\"Website\\\":null},{\\\"attributes\\\":{\\\"type\\\":\\\"Account\\\",\\\"url\\\":\\\"/services/data/v60.0/sobjects/Account/001U8000005cJN0IAM\\\"},\\\"Name\\\":\\\"Nike\\\",\\\"Id\\\":\\\"001U8000005cJN0IAM\\\",\\\"Website\\\":\\\"https://www.nike.com/\\\"},{\\\"attributes\\\":{\\\"type\\\":\\\"Account\\\",\\\"url\\\":\\\"/services/data/v60.0/sobjects/Account/001U8000005cRAnIAM\\\"},\\\"Name\\\":\\\"Google\\\",\\\"Id\\\":\\\"001U8000005cRAnIAM\\\",\\\"Website\\\":\\\"google.com\\\"}]\"}\n```\n\n#### CSV\n\n```elixir\nSFDCQuery.Client.Default.create(args)\n|> SFDCQuery.query(\"SELECT Id, Name, Website From Account LIMIT 3\")\n|> SFDCQuery.Parser.CSV.parse()\n\n{:ok, \"Id,Name,Website\\n001U8000005CeutIAC,Page,\\n001U8000005cJN0IAM,Nike,https://www.nike.com/\\n001U8000005cRAnIAM,Google,google.com\"}\n```","ref":"readme.html#parsing-the-response"},{"type":"extras","title":"Building your own Parser - SFDCQuery","doc":"You can build your parser using the behaviour `SFDCQuery.Parser.Behaviour`\n\n```elixir\ndefmodule MyApp.SFDCParser do\n  @behaviour SFDCQuery.Parser.Behaviour\n\n  alias SFDCQuery.Query\n\n  @impl true\n  def parse({:error, _} = error), do: error\n  def parse({:ok, %Query{records: records}}), do: {:ok, parse_records(records)}\nend\n```","ref":"readme.html#building-your-own-parser"},{"type":"extras","title":"Viewing the response - SFDCQuery","doc":"When debugging an Salesforce instance, it's useful to see the data in a view. To allow this, SFDCQuery allow to see the response in the terminal.\n\n#### Table\n\n```elixir\nSFDCQuery.Client.Default.create(args)\n|> SFDCQuery.query(\"SELECT Id, Name, Website From Account LIMIT 3\")\n|> SFDCQuery.View.Table.show()\n\nSELECT Id, Name, Website From Account LIMIT 3\n-------------------------------------------------------\n| Id                 | Name   | Website               |\n-------------------------------------------------------\n| 001U8000005CeutIAC | Page   |                       |\n| 001U8000005cJN0IAM | Nike   | https://www.nike.com/ |\n| 001U8000005cRAnIAM | Google | google.com            |\n```\n\n#### JSON\n\n```elixir\nSFDCQuery.Client.Default.create(args)\n|> SFDCQuery.query(\"SELECT Id, Name, Website From Account LIMIT 3\")\n|> SFDCQuery.View.JSON.show()\n\nSELECT Id, Name, Website From Account LIMIT 3\n-------------------------------------------------------\n[\n  {\n    \"attributes\": {\n      \"type\": \"Account\",\n      \"url\": \"/services/data/v60.0/sobjects/Account/001U8000005CeutIAC\"\n    },\n    \"Name\": \"Page\",\n    \"Id\": \"001U8000005CeutIAC\",\n    \"Website\": null\n  },\n  {\n    \"attributes\": {\n      \"type\": \"Account\",\n      \"url\": \"/services/data/v60.0/sobjects/Account/001U8000005cJN0IAM\"\n    },\n    \"Name\": \"Nike\",\n    \"Id\": \"001U8000005cJN0IAM\",\n    \"Website\": \"https://www.nike.com/\"\n  },\n  {\n    \"attributes\": {\n      \"type\": \"Account\",\n      \"url\": \"/services/data/v60.0/sobjects/Account/001U8000005cRAnIAM\"\n    },\n    \"Name\": \"Google\",\n    \"Id\": \"001U8000005cRAnIAM\",\n    \"Website\": \"google.com\"\n  }\n]\n```\n\n#### CSV\n\n```elixir\nSFDCQuery.Client.Default.create(args)\n|> SFDCQuery.query(\"SELECT Id, Name, Website From Account LIMIT 3\")\n|> SFDCQuery.View.CSV.show()\n\nSELECT Id, Name, Website From Account LIMIT 3\n-------------------------------------------------------\nId,Name,Website\n001U8000005CeutIAC,Page,\n001U8000005cJN0IAM,Nike,https://www.nike.com/\n001U8000005cRAnIAM,Google,google.com\n```","ref":"readme.html#viewing-the-response"},{"type":"extras","title":"Building your own View - SFDCQuery","doc":"You can build your parser using the behaviour `SFDCQuery.View.Behaviour`\n\n```elixir\ndefmodule MyApp.SFDCHTMLView do\n  @behaviour SFDCQuery.View.Behaviour\n\n  alias SFDCQuery.Query\n\n  @impl true\n  def show({:error, _} = error), do: error\n\n  def show({:ok, %Query{records: records}}) do\n    build_records_html(records)\n\n    :ok\n  end\nend\n```","ref":"readme.html#building-your-own-view"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,50,46,48]}}